@@ -5,6 +5,12 @@ import (
 	"fmt"
 )
 
+var (
+	itemsIDs []string
+	subIDs   []string
+	unsubIDs []string
+)
+
 const (
 	XMPPNS_PUBSUB       = "http://jabber.org/protocol/pubsub"
 	XMPPNS_PUBSUB_EVENT = "http://jabber.org/protocol/pubsub#event"
@@ -102,31 +108,39 @@ func pubsubUnsubscriptionStanza(node, jid string) string {
 }
 
 func (c *Client) PubsubSubscribeNode(node, jid string) error {
+	id := getUUIDv4()
+	subIDs = append(subIDs, id)
 	_, err := c.RawInformation(c.jid,
 		jid,
-		"sub1",
+		id,
 		"set",
 		pubsubSubscriptionStanza(node, c.jid))
 	return err
 }
 
 func (c *Client) PubsubUnsubscribeNode(node, jid string) error {
+	id := getUUIDv4()
+	unsubIDs = append(unsubIDs, id)
 	_, err := c.RawInformation(c.jid,
 		jid,
-		"unsub1",
+		id,
 		"set",
 		pubsubUnsubscriptionStanza(node, c.jid))
 	return err
 }
 
 func (c *Client) PubsubRequestLastItems(node, jid string) error {
+	id := getUUIDv4()
+	itemsIDs = append(itemsIDs, id)
 	body := fmt.Sprintf("<items node='%s'/>", node)
-	_, err := c.RawInformation(c.jid, jid, "items1", "get", pubsubStanza(body))
+	_, err := c.RawInformation(c.jid, jid, id, "get", pubsubStanza(body))
 	return err
 }
 
 func (c *Client) PubsubRequestItem(node, jid, id string) error {
+	stanzaID := getUUIDv4()
+	itemsIDs = append(itemsIDs, stanzaID)
 	body := fmt.Sprintf("<items node='%s'><item id='%s'/></items>", node, id)
-	_, err := c.RawInformation(c.jid, jid, "items3", "get", pubsubStanza(body))
+	_, err := c.RawInformation(c.jid, jid, stanzaID, "get", pubsubStanza(body))
 	return err
 }
